@@ -1,4 +1,6 @@
-__version__=0.7
+__version__=0.2
+
+### Load the FairDetect Class
 import time
 
 start_time = time.time()
@@ -10,7 +12,6 @@ import pandas as pd
 from plotly.subplots import make_subplots
 import plotly.graph_objects as go
 import dalex as dx
-import pandas as pd
 from scipy.stats import chi2_contingency
 from tabulate import tabulate
 from sklearn.metrics import confusion_matrix
@@ -18,14 +19,15 @@ from scipy.stats import chisquare
 from sklearn.metrics import precision_score
 
 
-class FairDetect:
+class Fairdetect:
     
     def __init__(self,model,X_test,y_test):
         self.model,self.X_test,self.y_test = model, X_test, y_test
     
     def check_for_target(self):
         """
-        Target variable label definition. Only binary target variable accepted
+        Allows user to define the target variable out of the columns available
+        Checks if target variable is Binary or not. Only binary target variable accepted
         
         Return
         ------
@@ -40,31 +42,14 @@ class FairDetect:
         
         return self.target_column
     
-    def check_for_sensitive(self):
-        """
-        Sensitive variable label definition. Only binary sensitive variable accepted
-        
-        Return
-        ------
-        Selection of the sensitive variable from all columns of the dataframe
-        """
-        print(data.columns.values)
-        self.sensitive_column = input("Please select sensitive column")
-        if not(set(data[self.sensitive_column].unique())==set([0,1])):
-            raise ValueError('Only binary sensitive variable')
-        else:
-            print("You choose wisely. Your sensitive variable is:", self.sensitive_column)
-
-        return self.sensitive_column   
-
-     
+    
     def create_labels(self,sensitive):
         """
-        Sensitive variable label definition. Only binary target variable accepted
+        Define labels for sensitive variable
         
         Parameters
         ----------
-        sensitive_label: Method allows user to input a string for each group of sensitive
+        create_labels: Method allows user to input a string for each group of sensitive variable
         """
         sensitive_label = {}
         for i in set(X_test[sensitive]):
@@ -74,6 +59,13 @@ class FairDetect:
         return(sensitive_label)
     
     def create_targetname(self,predictions):
+        """
+        Define labels for sensitive variable
+        
+        Parameters
+        ----------
+        create_targetname: Method allows user to input a string for each group of target variable
+        """
         print()
         print("Enter Target names below") 
         target_name = {}
@@ -85,12 +77,20 @@ class FairDetect:
         return(target_name)
     
     def get_sensitive_col(self):
+        """
+        Allows user to define the sensitive variable out of the columns available
+        Checks if sensitive variable is Binary or not. Only binary sensitive variable accepted
+        
+        Return
+        ------
+        Selection for the sensitive variable from all columns of the dataframe
+        """     
+        
         print("Please select the sensitive column name from given features")
         print(self.X_test.columns.values)
         sens_col=input("Enter sensitive column here : ")
         print()
         return sens_col
-
     
     def representation(self,X_test,y_test,sensitive,labels,predictions):
         """
@@ -155,6 +155,7 @@ class FairDetect:
         cont_table = (tabulate(contigency_pct_p.T, headers=labels.values(), tablefmt='fancy_grid'))
 
         return cont_table, sens_df, fig, p
+        
 
     
     def ability(self,sens_df,labels):
@@ -308,8 +309,6 @@ class FairDetect:
             print("Accept H0: False Negative Disparity Not Detected. p=",self.FNR_p)
 
 
-
-
     def predictive(self,labels,sens_df):
         
         """
@@ -365,7 +364,6 @@ class FairDetect:
         ------
         The p-values are calculated using the Chi test-statistic
         """
-        
         predictions = self.model.predict(self.X_test)
         target_names=self.create_targetname(predictions)
         cont_table,sens_df,rep_fig,rep_p = self.representation(self.X_test,self.y_test,sensitive,labels,predictions)
@@ -383,12 +381,13 @@ class FairDetect:
             print('\033[1;4m' +"* Reject H0: Significant Relation Between",sensitive,"and Target with p="+'\033[0m',rep_p)
         else:
             print("Accept H0: No Significant Relation Between",sensitive,"and Target Detected. p=",rep_p)
-        
+
         TPR, FPR, TNR, FNR = self.ability(sens_df,labels)
         print("\n\nABILITY")
         self.ability_plots(labels,TPR,FPR,TNR,FNR)
         self.ability_metrics(TPR,FPR,TNR,FNR)
-        
+
+
         precision_dic, pred_fig, pred_p = self.predictive(labels,sens_df)
         print("\n\nPREDICTIVE")
         pred_fig.show()
@@ -469,9 +468,7 @@ class FairDetect:
         Plots for each one of the available combinations sensitive vs. target variables compared to the base scenario: 
         variable relevance for all sensitive groups and all targets
         """       
-            
-        #labels=self.create_labels(sensitive)
-        
+       
         import shap
         explainer = shap.Explainer(self.model)
 
@@ -486,8 +483,6 @@ class FairDetect:
         misclass = full_table[full_table.t != full_table.p]
         affected_class = misclass[(misclass[sensitive] == affected_group) & (misclass.p == affected_target)]
         shap_values2 = explainer(affected_class.drop(['t','p'],axis=1))
-        #sens_mis_coh = np.where(affected_class[sensitive]==list(labels.keys())[0],labels[0],labels[1])
-
 
         figure,axes = plt.subplots(nrows=2, ncols=2,figsize=(20,10))
         plt.subplots_adjust(right=1.4,wspace=1)
@@ -498,11 +493,9 @@ class FairDetect:
         plt.subplot(1, 2, 2) # row 1, col 2 index 1
         shap_values2 = explainer(affected_class.drop(['t','p'],axis=1))
         shap.plots.bar(shap_values2)
-        #shap.plots.bar(shap_values2)
 
         full_table['t'] = self.y_test
         full_table['p'] = self.model.predict(self.X_test)
-        #full_table=full_table[['checking_account','credit_amount','duration','sex','t','p']]
 
         misclass = full_table[full_table.t != full_table.p]
         affected_class = misclass[(misclass[sensitive] == affected_group) & (misclass.p == affected_target)]
@@ -512,10 +505,6 @@ class FairDetect:
 
         x_axis = list(affected_class.drop(['t','p',sensitive],axis=1).columns)
         affect_character = list((affected_class.drop(['t','p',sensitive],axis=1).mean()-tru_class.drop(['t','p',sensitive],axis=1).mean())/affected_class.drop(['t','p',sensitive],axis=1).mean())
-
-        #plt.figsize([10,10])
-        #plt.bar(x_axis,affect_character)
-
         fig = go.Figure([go.Bar(x=x_axis, y=affect_character)])
 
         print("Affected Attribute Comparison")
@@ -525,15 +514,11 @@ class FairDetect:
         misclass = full_table[full_table.t != full_table.p]
         affected_class = misclass[(misclass[sensitive] == affected_group) & (misclass.p == affected_target)]
 
-        #truclass = full_table[full_table.t == full_table.p]
         tru_class = full_table[(full_table[sensitive] == affected_group) & (full_table.p == affected_target)]
 
         x_axis = list(affected_class.drop(['t','p',sensitive],axis=1).columns)
         affect_character = list((affected_class.drop(['t','p',sensitive],axis=1).mean()-full_table.drop(['t','p',sensitive],axis=1).mean())/affected_class.drop(['t','p',sensitive],axis=1).mean())
 
-        #plt.figsize([10,10])
-        #plt.bar(x_axis,affect_character)
-
         fig = go.Figure([go.Bar(x=x_axis, y=affect_character)])
         print("Average Comparison to All Members")
         fig.show()
